@@ -12,14 +12,18 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import re
 import base64
 import hashlib
+import threading
+
 from collections import namedtuple
 from .utils.enum import IntEnum
 from .exceptions import SpecificationError, RequirementError, ResultException
 from .baseobject import TestObject, Table
 from .baseobject import get, hash
 from .testtype import TestType
+
 import testflows._core.contrib.rsa as rsa
 
 class Result(TestObject, ResultException):
@@ -47,9 +51,11 @@ class Result(TestObject, ResultException):
     def __init__(self, message=None, reason=None, type=None, test=None, metrics=None, tickets=None, values=None):
         from .funcs import current
         self.test = test if test is not None else current().name
+        if not isinstance(self.test, str):
+            raise TypeError("test must be of 'str' type")
         self.type = get(type, self.type)
         if self.type is None:
-            raise TypeError("result type must be defined")
+            raise TypeError("type must be defined")
         self.message = message
         self.reason = reason
         self.metrics = get(metrics, list(self.metrics))
@@ -61,9 +67,6 @@ class Result(TestObject, ResultException):
     def value(self):
         return self.values[-1].value if self.values else None
 
-    def __reduce__(self):
-        raise TypeError("not serializable")
-
     def __call__(self, result=None):
         if result is None:
             result = getattr(self.__module__, str(self.type))
@@ -333,10 +336,113 @@ class ExamplesRow(TestObject):
         self.values = [str(value) for value in values]
         self.row_format = row_format
 
-class Secret(TestObject):
-    """RSA encrypted secret.
+class Secrets:
+    """Secrets registry.
     """
-    _fields = ("name", "code", "pubkey_id", "type", "group", "uid")
+    def __init__(self):
+        self._secrets = set()
+        self._filter_regex = re.compile(r"")
+        self._filter_secrets = []
+        self._lock = threading.Lock()
+    
+    def is_empty(self):
+        """Return True if registry is empty.
+        """
+        with self._lock:
+            return not bool(self._filter_secrets)
+
+    def register(self, secret):
+        """Register secret object.
+        """
+        with self._lock:
+            self._secrets.add(secret)
+            self._update_filter()
+
+    def unregister(self, secret):
+        """Unregister secret object.
+        """
+        with self._lock:
+            self._secrets.remove(secret)
+            self._update_filter()
+
+    def _update_filter(self):
+        """Update filter regex.
+        """
+        self._filter_secrets = [s for s in self._secrets if s.is_set()]
+        self._filter_regex = re.compile("|".join([f"(?P<{s.name}>{re.escape(s.value)})" for s in self._filter_secrets]))
+
+    def filter(self, message):
+        """Filter all secret values from message.
+        """
+        with self._lock:
+            return self._filter_regex.sub(lambda m: f"[masked]:{self._filter_secrets[m.lastindex-1]}", message)
+
+
+secrets_registry = Secrets()
+
+class Secret(TestObject):
+    """Secret value.
+    """
+    _fields = ("name", "type", "group", "uid")
+    _defaults = (None,) * 4
+    
+    uid = None
+    type = None
+    name = None
+    group = None
+
+    def __init__(self, name=None, type=None, group=None, uid=None):
+        self.name = get(name, self.name)
+        if self.name is None:
+            raise TypeError("name must be specified")
+        self.type = get(type, self.type)
+        self.group = get(group, self.group)
+        self.uid = get(uid, self.uid)
+        self._value = None
+
+    def clear(self):
+        self._value = None
+        return self
+
+    def __call__(self, value=None):
+        if value is not None:
+            self._value = str(value)
+            secrets_registry.register(self)
+
+        return self
+
+    def is_set(self):
+        """Return true if value has been set.
+        """
+        return self._value is not None
+
+    @property
+    def value(self):
+        """Return plaintext value of the secret.
+        """
+        if self._value is None:
+            raise ValueError("no value")
+        return self._value
+
+    def __str__(self):
+        return self.__repr__()
+
+    def __repr__(self):
+        """Custom object representation.
+        """
+        kwargs = []
+        for field in self._fields:
+            value = getattr(self, field)
+            if value is None:
+                continue
+            kwargs.append(f"{field}={repr(value)}")
+
+        return f"Secret({','.join(kwargs)})"
+
+class RSASecret(Secret):
+    """RSA encrypted secret value.
+    """
+    _fields = ("name", "type", "group", "uid", "code", "pubkey_id",)
     _defaults = (None,) * 6
     uid = None
     name = None
@@ -344,7 +450,7 @@ class Secret(TestObject):
     group = None
     encoding = "utf-8"
 
-    def __init__(self, name=None, code=None, pubkey_id=None, type=None, group=None, uid=None):
+    def __init__(self, name=None, type=None, group=None, uid=None, code=None, pubkey_id=None):
         self.name = get(name, None)
         self.type = get(type, self.type)
         self.group = get(group, self.group)
@@ -357,10 +463,6 @@ class Secret(TestObject):
 
         self.__call__(code=code)
 
-    def clear(self):
-        self._value = None
-        return self
-
     def __call__(self, value=None, code=None, private_key=None, public_key=None):
         if value is not None:
             self._value = str(value)
@@ -390,17 +492,6 @@ class Secret(TestObject):
 
         return self
 
-    @property
-    def value(self):
-        """Return plaintext value of the secret.
-        """
-        if self._value is None:
-            raise ValueError("no value")
-        return self._value
-
-    def __str__(self):
-        return self.__repr__()
-
     def __repr__(self):
         """Custom object representation.
         """
