@@ -13,12 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # to the end flag
-import asyncio
 import contextvars
+
 from collections import namedtuple
+
 from concurrent.futures import CancelledError
 from concurrent.futures import TimeoutError
 from concurrent.futures import Future as ConcurrentFuture
+
+from .asyncio import asyncio
 from .asyncio import Future as AsyncFuture
 from .asyncio import is_running_in_event_loop
 from .asyncio import TimeoutError as AsyncTimeoutError
@@ -130,9 +133,6 @@ def join(*futures, cancel=None, test=None, raise_exception=True):
             break
         future = futures.pop()
 
-        if not isinstance(future, ConcurrentFuture):
-            continue
-
         try:
             if cancel or len(exceptions) > 0 or test.terminating is not None or top_test.terminating is not None:
                 future.cancel()
