@@ -37,6 +37,7 @@ from .asyncio import GlobalAsyncPoolExecutor
 from ..asyncio import is_running_in_event_loop, wrap_future
 from ..service import BaseServiceObject, ServiceObjectType, process_service, auto_expose
 from .. import current, top, previous, _get_parallel_context
+from ...objects import Result
 
 _process_queues = weakref.WeakKeyDictionary()
 _shutdown = False
@@ -96,6 +97,7 @@ class WorkerSettings:
         self.show_retries = settings.show_retries
         self.trim = settings.trim
         self.random_order = settings.random_order
+        self.service_timeout = settings.service_timeout
         self.global_thread_pool = (
                 settings.global_thread_pool.__class__,
                 settings.global_thread_pool.initargs
@@ -110,7 +112,7 @@ class WorkerSettings:
         if obj is None:
             return obj
         if not isinstance(obj, BaseServiceObject):
-            obj = process_service().register(obj)
+            obj = process_service().register(obj, sync=True, awaited=False)
         return obj
 
 
@@ -152,6 +154,7 @@ class _WorkItem(object):
             settings.show_retries = work_settings.show_retries
             settings.trim = work_settings.trim
             settings.random_order = work_settings.random_order
+            settings.service_timeout = work_settings.service_timeout
             # set global thread pool
             settings.global_thread_pool = None
             if work_settings.global_thread_pool is not None:
@@ -181,9 +184,10 @@ class _WorkItem(object):
                 else:
                     result = self.fn(*self.args, **self.kwargs)
 
-            except BaseException:
-                exc_type, exc_value, exc_tb = sys.exc_info()
-                exc = exc_type(str(exc_value) + "\n\nWorker Traceback (most recent call last):\n" + "".join(traceback.format_tb(exc_tb)).rstrip())
+            except BaseException as exc:
+                if not isinstance(exc, Result):
+                    exc_type, exc_value, exc_tb = sys.exc_info()
+                    exc = exc_type(str(exc_value) + "\n\nWorker Traceback (most recent call last):\n" + "".join(traceback.format_tb(exc_tb)).rstrip())
                 self.future.set_exception(exc)
                 # Break a reference cycle with the exception 'exc'
                 self = None
@@ -192,7 +196,7 @@ class _WorkItem(object):
                 try:
                     self.future.set_result(result)
                 except TypeError:
-                    self.future.set_result(process_service().register(result))
+                    self.future.set_result(process_service().register(result, sync=True, awaited=False))
 
         ctx.run(runner, self)
 
@@ -252,7 +256,7 @@ class ProcessPoolExecutor(_base.Executor):
         self._open = False
         self._max_workers = max_workers
         self._raw_work_queue = queue.Queue()
-        self._work_queue = process_service().register(self._raw_work_queue)
+        self._work_queue = process_service().register(self._raw_work_queue, sync=True, awaited=False)
         self._processes = set()
         self._broken = False
         self._shutdown = False
@@ -289,11 +293,12 @@ class ProcessPoolExecutor(_base.Executor):
 
             service = process_service()
 
-            future = service.register(Future())
+            _raw_future = Future()
+            future = service.register(_raw_future, sync=True, awaited=False)
 
-            current_test = service.register(current())
-            previous_test = service.register(previous())
-            top_test = service.register(top())
+            current_test = service.register(current(), sync=True, awaited=False)
+            previous_test = service.register(previous(), sync=True, awaited=False)
+            top_test = service.register(top(), sync=True, awaited=False)
 
             work_item = _WorkItem(WorkerSettings(), current_test, previous_test, top_test, future, fn, args, kwargs)
 
@@ -306,9 +311,9 @@ class ProcessPoolExecutor(_base.Executor):
             work_item.run(local=True)
 
         if is_running_in_event_loop():
-            return wrap_future(future)
+            return wrap_future(_raw_future)
 
-        return future
+        return _raw_future
 
     def _adjust_process_count(self):
         """Increase worker count up to max_workers if needed.
